@@ -376,3 +376,17 @@ void PuntateMain::on_stream24_clicked()
     process.start("sh /opt/serviziopubblico/script/p24.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down25_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d25.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream25_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p25.sh");
+    process.waitForFinished();
+}
